@@ -21,6 +21,7 @@ from .const import (
     COLOR_MODE_RGBWW,
     EFFECT_MUSIC,
     EFFECT_RANDOM,
+    PRESET_MUSIC_MODE,
     STATE_BLUE,
     STATE_COOL_WHITE,
     STATE_GREEN,
@@ -109,6 +110,14 @@ class AIOWifiLedBulb(LEDENETDevice):
     async def async_setup(self, updated_callback: Callable[[], None]) -> None:
         """Setup the connection and fetch initial state."""
         self._updated_callback = updated_callback
+        try:
+            await self._async_setup()
+        except Exception:  # pylint: disable=broad-except
+            self._async_stop()
+            raise
+        return
+
+    async def _async_setup(self) -> None:
         await self._async_determine_protocol()
         assert self._protocol is not None
         if isinstance(self._protocol, ALL_IC_PROTOCOLS):
@@ -142,7 +151,9 @@ class AIOWifiLedBulb(LEDENETDevice):
             await asyncio.wait_for(self._power_restore_future, timeout=self.timeout)
         except asyncio.TimeoutError:
             self.set_unavailable()
-            raise RuntimeError("Could not determine power restore state")
+            raise RuntimeError(
+                f"{self.ipaddr}: Could not determine power restore state"
+            )
 
     async def _async_device_config_setup(self) -> None:
         """Setup an addressable light."""
@@ -161,7 +172,7 @@ class AIOWifiLedBulb(LEDENETDevice):
             await asyncio.wait_for(self._device_config_future, timeout=self.timeout)
         except asyncio.TimeoutError:
             self.set_unavailable()
-            raise RuntimeError("Could not determine number pixels")
+            raise RuntimeError(f"{self.ipaddr}: Could not determine number pixels")
 
     async def async_stop(self) -> None:
         """Shutdown the connection."""
@@ -214,6 +225,7 @@ class AIOWifiLedBulb(LEDENETDevice):
     async def async_turn_on(self) -> bool:
         """Turn on the device."""
         calls = (
+            self._async_turn_on,
             self._async_turn_on,
             self._async_turn_on,
             self._async_turn_off_on,
@@ -269,7 +281,7 @@ class AIOWifiLedBulb(LEDENETDevice):
         if self.rgbw_color_temp_support(self.color_modes):
             await self.async_set_levels(cold, cold, cold, warm, 0, persist=persist)
         else:
-            await self.async_set_levels(0, 0, 0, warm, cold, persist=persist)
+            await self.async_set_levels(None, None, None, warm, cold, persist=persist)
 
     async def async_update(self) -> None:
         """Request an update.
@@ -298,14 +310,14 @@ class AIOWifiLedBulb(LEDENETDevice):
                 self._aio_protocol.close()
             self.set_unavailable()
             self._updates_without_response = 0
-            raise RuntimeError("Bulb stopped responding")
+            raise RuntimeError(f"{self.ipaddr}: Bulb stopped responding")
         await self._async_send_state_query()
         self._updates_without_response += 1
 
     def _async_raise_if_offline(self) -> None:
         """Raise RuntimeError if the bulb is offline."""
         if not self.available:
-            raise RuntimeError("Bulb not responding, too soon to retry")
+            raise RuntimeError(f"{self.ipaddr}: Bulb not responding, too soon to retry")
 
     async def async_set_levels(
         self,
@@ -337,12 +349,14 @@ class AIOWifiLedBulb(LEDENETDevice):
     ) -> None:
         """Process and send a levels change."""
         self._set_transition_complete_time()
+        if updates:
+            self._replace_raw_state(updates)
         for idx, msg in enumerate(msgs):
             await self._async_send_msg(msg)
             if idx > 0:
+                self._process_futures_and_callbacks()
                 await asyncio.sleep(COMMAND_SPACING_DELAY)
-        if updates:
-            self._replace_raw_state(updates)
+                self._set_transition_complete_time()
 
     async def async_set_preset_pattern(
         self, effect: int, speed: int, brightness: int = 100
@@ -409,6 +423,8 @@ class AIOWifiLedBulb(LEDENETDevice):
         assert self._protocol is not None
         if not self.microphone:
             raise ValueError("{self.model} does not have a built-in microphone")
+        self._set_preset_pattern_transition_complete_time()
+        self._replace_raw_state({"preset_pattern": PRESET_MUSIC_MODE})
         for idx, bytes_send in enumerate(
             self._protocol.construct_music_mode(
                 sensitivity or 100,
@@ -508,20 +524,20 @@ class AIOWifiLedBulb(LEDENETDevice):
         # change two values before the first one has been updated
         async with self._device_config_lock:
             device_config = self.model_data.device_config
+            ic_type_to_num = device_config.ic_type_to_num
+            operating_mode_to_num = device_config.operating_mode_to_num
+            if self._device_config is not None:
+                wiring_to_num = self._device_config.wiring_to_num
+            else:
+                wiring_to_num = device_config.wiring_to_num
             operating_mode_num = (
                 self.operating_mode_num
                 if operating_mode is None
-                else device_config.operating_mode_to_num[operating_mode]
-            )
-            wiring_num = (
-                self.wiring_num
-                if wiring is None
-                else device_config.wiring_to_num[wiring]
+                else operating_mode_to_num[operating_mode]
             )
+            wiring_num = self.wiring_num if wiring is None else wiring_to_num[wiring]
             ic_type_num = (
-                self.ic_type_num
-                if ic_type is None
-                else device_config.ic_type_to_num[ic_type]
+                self.ic_type_num if ic_type is None else ic_type_to_num[ic_type]
             )
             assert self._protocol is not None
             assert not isinstance(self._protocol, ProtocolLEDENETOriginal)
@@ -783,4 +799,4 @@ class AIOWifiLedBulb(LEDENETDevice):
                 else:
                     return
         self.set_unavailable()
-        raise RuntimeError("Cannot determine protocol")
+        raise RuntimeError(f"{self.ipaddr}: Cannot determine protocol")
