@@ -384,7 +384,7 @@ HARDWARE = [
         dimmable_effects=False,
     ),
     LEDENETHardware(
-        model="AK001-ZJ210",  # might also be "AK001-ZJ2100"
+        model="AK001-ZJ210",
         chip=LEDENETChip.ESP8266,  # verified
         remote_rf=False,  # verified
         remote_24g=False,
@@ -694,7 +694,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x07,
-        # "AK001-ZJ2146" == v2 has RF remote support
+        # "AK001-ZJ2146" == v2.06 has RF remote support
         models=["AK001-ZJ2146"],
         description="Controller RGBCW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
@@ -711,12 +711,13 @@ MODELS = [
     LEDENETModel(
         model_num=0x08,
         # AK001-ZJ2101 is v1
-        # AK001-ZJ2145 is v2.11
+        # AK001-ZJ2145 is v2.11 (Upgradable to v2.15)
         models=["AK001-ZJ2101", "AK001-ZJ2145", "AK001-ZJ2147"],
         description="Controller RGB with MIC",
         always_writes_white_and_colors=True,  # Formerly rgbwprotocol
         protocols=[
             MinVersionProtocol(2, PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS),
+            MinVersionProtocol(1, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
             MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE),
         ],
         mode_to_color_mode=GENERIC_RGB_MAP,
@@ -922,7 +923,7 @@ MODELS = [
         # 'AK001-ZJ200' == v2 - some devices have RF remote support (the mini ones)
         models=["HF-LPB100-ZJ200", "AK001-ZJ200"],
         description="Controller RGB/WW/CW",
-        always_writes_white_and_colors=False,  # Formerly rgbwprotocol
+        always_writes_white_and_colors=True,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_9BYTE)],
         mode_to_color_mode=BASE_MODE_MAP,
         color_modes={COLOR_MODE_RGBWW},  # Formerly rgbwcapable
@@ -933,13 +934,16 @@ MODELS = [
     LEDENETModel(
         model_num=0x33,
         # 'AK001-ZJ100' == v3 - WIFI370 version
+        # 'AK001-ZJ210' == v6.37 - Seen on the outdoor string lights from Lytworx
         # 'AK001-ZJ2104' == v7 supports turning on by effect/levels set
+        # 'AK001-ZJ2134' == v8.02 - seen on the water proof controllers for outdoor garden light
         # 'AK001-ZJ2101' == v8.61, 8.62 (44 key) - no dimmable effects confirmed, confirmed auto on
         # "AK001-ZJ2145" == v9 # no rf support!
-        # "AK001-ZJ2145" == v9.27, 9.33 # w/IR
+        # "AK001-ZJ2145" == v9.27, 9.30, 9.33 # w/IR
         # "AK001-ZJ2146" == v10.48 # 2.4ghz support
         # "AK001-ZJ2148" == v10.63 # 2.4ghz support, confirmed to be able to change 2.4G remote settings
         models=[
+            "AK001-ZJ100",
             "AK001-ZJ210",
             "AK001-ZJ2104",
             "AK001-ZJ2101",
@@ -1177,7 +1181,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0xA3,
-        # AK001-ZJ2147 v1.19 has RF remote support
+        # AK001-ZJ2147 v1.17, v1.19 has RF remote support
         # AK001-ZJ2148 v1.26, v1.27 has RF remote support, confirmed to be able to change 2.4G remote settings
         models=["AK001-ZJ2147", "AK001-ZJ2148"],
         description="Addressable v3",
